Augmentations (albumentations.augmentations)
============================================

Transforms
----------
.. automodule:: albumentations.augmentations.transforms
    :members:

Functional transforms
---------------------
.. automodule:: albumentations.augmentations.functional
    :members:
